@@ -11,9 +11,14 @@ Miscellaneous Data I/O
 
    {}
 """
-__all__ = ['write_polygon_to_text', 'to_pickle', 'from_pickle',
-           'get_radiosonde', 'get_membership_functions']
-__doc__ = __doc__.format('\n   '.join(__all__))
+__all__ = [
+    "write_polygon_to_text",
+    "to_pickle",
+    "from_pickle",
+    "get_radiosonde",
+    "get_membership_functions",
+]
+__doc__ = __doc__.format("\n   ".join(__all__))
 
 import datetime as dt
 import io
@@ -27,10 +32,10 @@ from wradlib import util
 
 
 def _write_polygon_to_txt(f, idx, vertices):
-    f.write('%i %i\n' % idx)
+    f.write("%i %i\n" % idx)
     for i, vert in enumerate(vertices):
-        f.write('%i ' % (i,))
-        f.write('%f %f %f %f\n' % tuple(vert))
+        f.write("%i " % (i,))
+        f.write("%f %f %f %f\n" % tuple(vert))
 
 
 def write_polygon_to_text(fname, polygons):
@@ -79,19 +84,19 @@ def write_polygon_to_text(fname, polygons):
         3 0.000000 0.000000 0.000000 0.000000
         END
     """
-    with open(fname, 'w') as f:
-        f.write('Polygon\n')
+    with open(fname, "w") as f:
+        f.write("Polygon\n")
         count = 0
         for vertices in polygons:
             _write_polygon_to_txt(f, (count, 0), vertices)
             count += 1
-        f.write('END\n')
+        f.write("END\n")
 
 
 def to_pickle(fpath, obj):
     """Pickle object <obj> to file <fpath>
     """
-    output = open(fpath, 'wb')
+    output = open(fpath, "wb")
     pickle.dump(obj, output)
     output.close()
 
@@ -99,7 +104,7 @@ def to_pickle(fpath, obj):
 def from_pickle(fpath):
     """Return pickled object from file <fpath>
     """
-    pkl_file = open(fpath, 'rb')
+    pkl_file = open(fpath, "rb")
     obj = pickle.load(pkl_file)
     pkl_file.close()
     return obj
@@ -139,11 +144,13 @@ def get_radiosonde(wmoid, date, cols=None):
     hour = "12" if (6 < int(hour) < 18) else "00"
 
     # url
-    url_str = ("http://weather.uwyo.edu/cgi-bin/sounding?"
-               "TYPE=TEXT%3ALIST&"
-               "YEAR={0}&MONTH={1}&"
-               "FROM={2}{3}&TO={2}{3}&STNM={4}&"
-               "ICE=1".format(year, month, day, hour, wmoid))
+    url_str = (
+        "http://weather.uwyo.edu/cgi-bin/sounding?"
+        "TYPE=TEXT%3ALIST&"
+        "YEAR={0}&MONTH={1}&"
+        "FROM={2}{3}&TO={2}{3}&STNM={4}&"
+        "ICE=1".format(year, month, day, hour, wmoid)
+    )
 
     # html request
     with urllib.request.urlopen(url_str) as url_request:
@@ -154,7 +161,7 @@ def get_radiosonde(wmoid, date, cols=None):
 
     # first line (eg errormessage)
     if url_text.find("<H2>") == -1:
-        err = url_text.split('\n', 1)[1].split('\n', 1)[0]
+        err = url_text.split("\n", 1)[1].split("\n", 1)[0]
         raise ValueError(err)
 
     # extract relevant information
@@ -162,7 +169,7 @@ def get_radiosonde(wmoid, date, cols=None):
     url_meta = url_text.split("<PRE>")[2].split("</PRE>")[0]
 
     # extract empty lines, names, units and data
-    _, _, names, units, _, url_data = url_data.split('\n', 5)
+    _, _, names, units, _, url_data = url_data.split("\n", 5)
 
     names = names.split()
     units = units.split()
@@ -171,31 +178,33 @@ def get_radiosonde(wmoid, date, cols=None):
 
     # read data
     with warnings.catch_warnings():
-        warnings.filterwarnings('ignore', category=UserWarning)
-        data = np.genfromtxt(io.StringIO(url_data),
-                             names=names,
-                             dtype=float,
-                             usecols=cols,
-                             autostrip=True,
-                             invalid_raise=False)
+        warnings.filterwarnings("ignore", category=UserWarning)
+        data = np.genfromtxt(
+            io.StringIO(url_data),
+            names=names,
+            dtype=float,
+            usecols=cols,
+            autostrip=True,
+            invalid_raise=False,
+        )
 
     # read metadata
     meta = {}
     for i, row in enumerate(io.StringIO(url_meta)):
         if i == 0:
             continue
-        k, v = row.split(':')
+        k, v = row.split(":")
         k = k.strip()
         v = v.strip()
         if i == 2:
             v = int(v)
         elif i == 3:
-            v = dt.datetime.strptime(v, '%y%m%d/%H%M')
+            v = dt.datetime.strptime(v, "%y%m%d/%H%M")
         elif i > 3:
             v = float(v)
         meta[k] = v
 
-    meta['quantity'] = {item: unitdict[item] for item in data.dtype.names}
+    meta["quantity"] = {item: unitdict[item] for item in data.dtype.names}
 
     return data, meta
 
@@ -214,19 +223,19 @@ def get_membership_functions(filename):
         Array of membership funcions with shape (hm-classes, observables,
         indep-ranges, 5)
     """
-    gzip = util.import_optional('gzip')
+    gzip = util.import_optional("gzip")
 
-    with gzip.open(filename, 'rb') as f:
-        nclass = int(f.readline().decode().split(':')[1].strip())
-        nobs = int(f.readline().decode().split(':')[1].strip())
+    with gzip.open(filename, "rb") as f:
+        nclass = int(f.readline().decode().split(":")[1].strip())
+        nobs = int(f.readline().decode().split(":")[1].strip())
         with warnings.catch_warnings():
-            warnings.filterwarnings('ignore', category=UserWarning)
-            data = np.genfromtxt(f, skip_header=10, autostrip=True,
-                                 invalid_raise=False)
+            warnings.filterwarnings("ignore", category=UserWarning)
+            data = np.genfromtxt(f, skip_header=10, autostrip=True, invalid_raise=False)
 
     data = np.reshape(data, (nobs, int(data.shape[0] / nobs), data.shape[1]))
-    msf = np.reshape(data, (data.shape[0], nclass, int(data.shape[1] / nclass),
-                            data.shape[2]))
+    msf = np.reshape(
+        data, (data.shape[0], nclass, int(data.shape[1] / nclass), data.shape[2])
+    )
     msf = np.swapaxes(msf, 0, 1)
 
     return msf
